[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Build Status](https://travis-ci.com/dwallace0723/pystitch.svg?branch=master)](https://travis-ci.com/dwallace0723/pystitch)
[![Python Versions](https://img.shields.io/badge/python-3.6%20%7C%203.7-blue.svg)](https://pypi.python.org/pypi/ansicolortags/)

# pystitch
a Python SDK for the Stitch Connect API
